@@ -1,12 +1,11 @@
-#!/usr/bin/env python
-# -*- coding: UTF-8 -*-
-from .openapi import TuyaOpenAPI, TuyaTokenInfo
-from .openmq import TuyaOpenMQ
 from .asset import TuyaAssetManager
-from .device import TuyaDeviceManager, TuyaDevice, TuyaDeviceListener
-from .project_type import ProjectType
+from .device import TuyaDevice, TuyaDeviceListener, TuyaDeviceManager
 from .home import TuyaHomeManager, TuyaScene
-from .logging import tuya_logger
+from .infrared import TuyaRemote
+from .openapi import TuyaOpenAPI, TuyaTokenInfo
+from .openlogging import TUYA_LOGGER
+from .openmq import TuyaOpenMQ
+from .tuya_enums import AuthType, TuyaCloudOpenAPIEndpoint
 from .version import VERSION
 
 __all__ = [
@@ -17,8 +16,10 @@ __all__ = [
     "TuyaDeviceManager",
     "TuyaDevice",
     "TuyaDeviceListener",
-    "ProjectType",
+    "AuthType",
+    "TuyaCloudOpenAPIEndpoint",
     "TuyaHomeManager",
-    "tuya_logger"
+    "TuyaScene",
+    "TUYA_LOGGER",
 ]
 __version__ = VERSION
